<?php
	/**
	* phpGroupWare - DEMO: A demo application.
	*
	* @author Sigurd Nes <sigurdne@online.no>
	* @copyright Copyright (C) 2003-2005 Free Software Foundation, Inc. http://www.fsf.org/
	* @license http://www.gnu.org/licenses/gpl.html GNU General Public License
	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
	* @package demo
	* @subpackage core
 	* @version $Id: hook_settings.inc.php 18358 2007-11-27 04:43:37Z skwashd $
	*/

	//$this->currentapp			= $GLOBALS['phpgw_info']['flags']['currentapp'];

	$yes_and_no = array(
		'True' => 'Yes',
		''     => 'No'
	);

